@@ -1,8 +1,8 @@
 test_that("Variable names are labeled", {
   skip_on_cran()
   skip_if_offline()
-  expect_equal(label_eurostat_vars("geo"), "Geopolitical entity (reporting)")
-  expect_equal(label_eurostat_vars("housing", lang = "fr"), "Habitation")
+  expect_equal(label_eurostat_vars(id = "nama_10_lp_ulc", x = "geo", lang = "en"), "Geopolitical entity (reporting)")
+  expect_equal(label_eurostat_tables("nama_10_lp_ulc"), "Labour productivity and unit labour costs")
 
   expect_true(any(grepl(
     "_code",
@@ -75,3 +75,13 @@ test_that("custom_dic works", {
     c("Finland", "Germany")
   )
 })
+
+test_that("wrong code (for this dataset) produces an error", {
+  skip_on_cran()
+  skip_if_offline()
+  expect_error(
+    label_eurostat(
+      get_eurostat("road_eqr_trams"), code = "coef"
+    )
+  )
+})
\ No newline at end of file
